@@ -279,7 +279,7 @@ class TftpServerState(TftpState):
         # root directory
         self.full_path = os.path.abspath(full_path)
         log.debug("full_path is %s", full_path)
-        if self.full_path.startswith(self.context.root):
+        if self.full_path.startswith(os.path.normpath(self.context.root) + os.sep):
             log.info("requested file is in the server root - good")
         else:
             log.warning("requested file is not within the server root - bad")
@@ -315,7 +315,7 @@ class TftpStateServerRecvRRQ(TftpServerState):
                 self.sendError(TftpErrors.FileNotFound)
                 raise TftpException("File not found: %s" % path)
         else:
-            log.warn("File not found: %s", path)
+            log.warning("File not found: %s", path)
             self.sendError(TftpErrors.FileNotFound)
             raise TftpException("File not found: {}".format(path))
 
